@@ -57,7 +57,7 @@ EXP const char*   musicxmllibVersionStr();
 
 The library includes a high level API to convert from the MusicXML format to the
 Guido Music Notation (GMN) format. For more information about this format, 
-see  http://guidolib.sourceforge.net
+see  https://guidodoc.grame.fr
 @{
 */
 
